# regexp-loop

> It executes the specified regexp for the given text and executes the callback with the match. If a global regexp is used, it creates a loop.

## Install
```sh
$ npm install --save regexp-loop
```

And then in your code:
```sh
const regexLoop = require('regex-loop')
```

## Basic use
The function expects three parameters:
* Regular expression *{RegExp}*
* Text *{String}*
* Callback function, the match will be passed as parameter *{function}*
```javascript
// Saving all matches from text

const
matches   = [],
regexLoop = require('regex-loop'),
text      = `Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit amet.`,
callback  = (match) => {
  matches.push(match[0])
}

regexLoop(/ipsum/gi, text, callback)

console.log(matches) // ["ipsum", "ipsum"]
```

## Dev Dependencies
| Module | Description |
| ------ | ------ |
| [@babel/core](https://babeljs.io/) | Babel is a toolchain that is mainly used to convert ECMAScript 2015+ code into a backwards compatible version of JavaScript in current and older browsers or environments.  |
| [@babel/preset-env](https://babeljs.io/docs/en/babel-preset-env) | @babel/preset-env is a smart preset that allows you to use the latest JavaScript without needing to micromanage which syntax transforms (and optionally, browser polyfills) are needed by your target environment(s). This both makes your life easier and JavaScript bundles smaller! |
| [jsdoc](http://usejsdoc.org/) |  JSDoc is a markup language used to annotate JavaScript source code files. Using comments containing JSDoc, programmers can add documentation describing the application programming interface of the code they're creating. |
| [tui-jsdoc-template](https://github.com/nhnent/tui.jsdoc-template) | Toast UI JSDoc template |
| [mocha](https://mochajs.org/) | Mocha is a feature-rich JavaScript test framework running on Node.js and in the browser, making asynchronous testing simple and fun. |
| [chai](https://www.chaijs.com/) | Chai is a BDD / TDD assertion library for node and the browser that can be delightfully paired with any javascript testing framework. |
| [mochawesome](https://adamgruber.github.io/mochawesome/) | Mochawesome is a custom reporter for the testing framework, mocha. It generates a full fledged HTML/CSS report that helps visualize your test suites. |
| [nyc](https://github.com/istanbuljs/nyc) | Istanbul instruments your ES5 and ES2015+ JavaScript code with line counters, so that you can track how well your unit-tests exercise your codebase. The nyc command-line-client for Istanbul works well with most JavaScript testing frameworks: tap, mocha, AVA, etc. |
| [eslint](https://eslint.org/) | ESLint is an open source project originally created by Nicholas C. Zakas in June 2013. Its goal is to provide a pluggable linting utility for JavaScript. |
| [eslint-config-standard](https://github.com/standard/eslint-config-standard) | An ESLint Shareable Config for JavaScript Standard Style |
| [eslint-plugin-import](https://www.npmjs.com/package/eslint-plugin-import) | This plugin intends to support linting of ES2015+ (ES6+) import/export syntax, and prevent issues with misspelling of file paths and import names. All the goodness that the ES2015+ static module syntax intends to provide, marked up in your editor. |
| [eslint-plugin-node](https://github.com/mysticatea/eslint-plugin-node) | Additional ESLint's rules for Node.js |
| [eslint-plugin-promise](https://github.com/xjamundx/eslint-plugin-promise) | Enforce best practices for JavaScript promises. |
| [eslint-plugin-standard](https://github.com/standard/eslint-plugin-standard) | ESlint Rules for the Standard Linter |
